about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c')
-rw-r--r--sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c b/sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c
index aa170d05ea..0fe8780cba 100644
--- a/sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c
+++ b/sysdeps/unix/sysv/linux/tst-socket-timestamp-compat.c
@@ -77,7 +77,7 @@ static void
 do_test_large_buffer (bool mc)
 {
   struct mmsghdr mmhdr = { 0 };
   /* It should be large enought for either timeval/timespec and the
      64 time type as well.  */
 
   union
@@ -142,7 +142,7 @@ do_test_large_buffer (bool mc)
 
 /* Check if recvmsg does not create the additional 64 bit timestamp if
    only 32 bit timestamp is enabled if the ancillary buffer is not large
-   enought.  Also checks if MSG_CTRUNC is set iff for 64 bit recvmsg
+   enough.  Also checks if MSG_CTRUNC is set iff for 64 bit recvmsg
    symbol.  */
 static void
 do_test_small_buffer (bool mc)
@@ -77,7 +77,7 @@ static void
 {
   struct mmsghdr mmhdr = { 0 };
-  /* It should be large enought for either timeval/timespec and the
+  /* It should be large enough for either timeval/timespec and the
      64 time type as well.  */
 